import { Application } from "express";
import authenticated from "../middlewares/auth/authenticated";
import cardImageStorage from "../middlewares/files/cardImageStorage";
import multer from "multer";
import profilePictureStorage from "../middlewares/files/profilePictureStorage";
import responseUser from "../middlewares/user/responseUser";
import uploadCardImage from "../middlewares/files/uploadCardImage";
import uploadProfilePicture from "../middlewares/files/uploadProfilePicture";

const cardImageUpload = multer({ storage: cardImageStorage });
const profilePictureUpload = multer({ storage: profilePictureStorage });

const fileRoute = (app: Application): void => {
  app.post(
    "/api/v1/files/card",
    cardImageUpload.single("card_image"),
    uploadCardImage()
  );
  app.post(
    "/api/v1/files/profile",
    authenticated(),
    profilePictureUpload.single("profile_picture"),
    uploadProfilePicture()
  );
};

export default fileRoute;
